@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2021 Greenbone Networks GmbH
+/* Copyright (C) 2009-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -30,7 +30,7 @@
 typedef GPtrArray array_t;
 
 GPtrArray *
-make_array ();
+make_array (void);
 
 void
 array_reset (array_t **array);
