@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2021 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -29,6 +29,8 @@
 
 #include "logging.h"
 
+#include "gvm_sentry.h" /* for gvm_sentry_log */
+
 #include <errno.h>  /* for errno */
 #include <libgen.h> /* for dirname */
 #include <stdio.h>  /* for fflush, fprintf, stderr */
@@ -626,6 +628,9 @@ gvm_log_func (const char *log_domain, GLogLevelFlags log_level,
                             message);
   g_free (prepend);
 
+  if (log_level <= G_LOG_LEVEL_WARNING)
+    gvm_sentry_log (message);
+
   gvm_log_lock ();
   /* Output everything to stderr if logfile is "-". */
   if (g_ascii_strcasecmp (log_file, "-") == 0)
