@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2021 Greenbone Networks GmbH
+/* Copyright (C) 2009-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -441,7 +441,6 @@ typedef struct nvti
   GSList *prefs;      /**< @brief Collection of NVT preferences */
 
   // The following are not settled yet.
-  gint timeout;  /**< @brief Default timeout time for this NVT */
   gint category; /**< @brief The category, this NVT belongs to */
   gchar *family; /**< @brief Family the NVT belongs to */
 } nvti_t;
@@ -936,6 +935,36 @@ nvti_severity_score (const nvti_t *n)
   return score;
 }
 
+/**
+ * @brief Get the severity score
+ *
+ * Extended severity was introduced but still not all
+ * vts are using it. Therefore it must be checked if
+ * we can calculate the score from the severity_vector tag
+ * or if we have to calculate it from the deprecated
+ * cvss_base_vector tag.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @return The severity_vector if present or cvss_base_vector otherwise.
+ * NULL indicates an error. Must be free()'d by the caller.
+ */
+gchar *
+nvti_severity_vector_from_tag (const nvti_t *n)
+{
+  gchar *vector;
+
+  /* Currently, only one severity_vector can be stored as tag.
+   * Therfore we just check this one. */
+  vector = nvti_get_tag (n, "severity_vector");
+  if (vector)
+    return vector;
+
+  vector = nvti_get_tag (n, "cvss_base_vector");
+
+  return vector;
+}
+
 /**
  * @brief Get the solution.
  *
@@ -1212,20 +1241,6 @@ nvti_pref (const nvti_t *n, guint p)
   return n ? g_slist_nth_data (n->prefs, p) : NULL;
 }
 
-/**
- * @brief Get the timeout for this NVT.
- *
- * @param n The NVT Info structure of which the timeout should
- *          be returned.
- *
- * @return The timeout integer number. A value <= 0 indicates it is not set.
- */
-gint
-nvti_timeout (const nvti_t *n)
-{
-  return n ? n->timeout : -1;
-}
-
 /**
  * @brief Get the category for this NVT.
  *
@@ -1808,25 +1823,6 @@ nvti_set_family (nvti_t *n, const gchar *family)
   return 0;
 }
 
-/**
- * @brief Set the timeout of a NVT Info.
- *
- * @param n The NVT Info structure.
- *
- * @param timeout The timeout to set. Values <= 0 will indicate it is not set.
- *
- * @return 0 for success. Anything else indicates an error.
- */
-int
-nvti_set_timeout (nvti_t *n, const gint timeout)
-{
-  if (!n)
-    return -1;
-
-  n->timeout = timeout;
-  return 0;
-}
-
 /**
  * @brief Set the category type of a NVT Info.
  *
