@@ -1,4 +1,4 @@
-/* Copyright (C) 2020-2021 Greenbone Networks GmbH
+/* Copyright (C) 2020-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -23,7 +23,14 @@
 #include "alivedetection.h"
 #include "boreas_error.h"
 
+boreas_error_t
+run_cli_extended (gvm_hosts_t *, alive_test_t, const gchar *,
+                  const unsigned int);
+
 boreas_error_t
 run_cli (gvm_hosts_t *, alive_test_t, const gchar *);
 
+boreas_error_t
+is_host_alive (const char *, int *);
+
 #endif /* not CLI_H */
