@@ -1,4 +1,4 @@
-/* Copyright (C) 2014-2021 Greenbone Networks GmbH
+/* Copyright (C) 2014-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -152,7 +152,8 @@ osp_connection_new (const char *host, int port, const char *cacert,
         }
 
       addr.sun_family = AF_UNIX;
-      strncpy (addr.sun_path, host, sizeof (addr.sun_path) - 1);
+      memset (addr.sun_path, 0, sizeof (addr.sun_path));
+      memcpy (addr.sun_path, host, sizeof (addr.sun_path) - 1);
       len = strlen (addr.sun_path) + sizeof (addr.sun_family);
       if (connect (connection->socket, (struct sockaddr *) &addr, len) == -1)
         {
@@ -248,6 +249,100 @@ osp_connection_close (osp_connection_t *connection)
   g_free (connection);
 }
 
+/**
+ * @brief Gets additional status info about the feed.
+ *
+ * The lockfile_in_use and self_test_exit_error fields will be set to -1 if
+ * the corresponding elements are missing.
+ *
+ * @param[in]   connection            Connection to an OSP server.
+ * @param[out]  lockfile_in_use       Whether the lockfile is in use.
+ * @param[out]  self_test_exit_error  Whether the sync script self check failed.
+ * @param[out]  self_test_error_msg   Self check error message if one occurred.
+ * @param[out]  cmd_error             Error message of the OSP command.
+ *
+ * @return 0 if success, 1 if error.
+ */
+int
+osp_check_feed (osp_connection_t *connection, int *lockfile_in_use,
+                int *self_test_exit_error, char **self_test_error_msg,
+                char **cmd_error)
+{
+  entity_t entity, feed, lockfile_entity, exit_error_entity, error_msg_entity;
+  const char *status, *status_text;
+
+  if (!connection)
+    return 1;
+
+  if (osp_send_command (connection, &entity, "<check_feed/>"))
+    return 1;
+
+  status = entity_attribute (entity, "status");
+
+  if (status != NULL && !strcmp (status, "400"))
+    {
+      status_text = entity_attribute (entity, "status_text");
+      g_debug ("%s: %s - %s.", __func__, status, status_text);
+      if (cmd_error)
+        *cmd_error = g_strdup (status_text);
+      free_entity (entity);
+      return 1;
+    }
+
+  feed = entity_child (entity, "feed");
+  if (!feed)
+    {
+      g_warning ("%s: element FEED missing.", __func__);
+      free_entity (entity);
+      return 1;
+    }
+
+  lockfile_entity = entity_child (feed, "lockfile_in_use");
+  exit_error_entity = entity_child (feed, "self_test_exit_error");
+  error_msg_entity = entity_child (feed, "self_test_error_msg");
+
+  if (lockfile_in_use)
+    {
+      if (lockfile_entity)
+        *lockfile_in_use = atoi (entity_text (lockfile_entity));
+      else
+        {
+          g_warning ("%s: element LOCKFILE_IN_USE missing.", __func__);
+          *lockfile_in_use = -1;
+        }
+    }
+
+  if (self_test_exit_error)
+    {
+      if (exit_error_entity)
+        *self_test_exit_error = atoi (entity_text (exit_error_entity));
+      else
+        {
+          g_warning ("%s: element SELF_TEST_EXIT_ERROR missing.", __func__);
+          *self_test_exit_error = -1;
+        }
+    }
+
+  if (self_test_error_msg)
+    {
+      if (self_test_error_msg)
+        {
+          if (entity_text (error_msg_entity))
+            *self_test_error_msg = g_strdup (entity_text (error_msg_entity));
+          else
+            *self_test_error_msg = NULL;
+        }
+      else
+        {
+          g_warning ("%s: element SELF_TEST_ERROR_MSG missing.", __func__);
+          *self_test_error_msg = NULL;
+        }
+    }
+
+  free_entity (entity);
+  return 0;
+}
+
 /**
  * @brief Get the scanner version from an OSP server.
  *
@@ -392,6 +487,74 @@ osp_get_vts_version (osp_connection_t *connection, char **vts_version,
   return 0;
 }
 
+/**
+ * @brief Get the VTs version as well as other feed info from an OSP server.
+ *
+ * @param[in]   connection    Connection to an OSP server.
+ * @param[out]  vts_version   Parsed VTs feed version.
+ * @param[out]  feed_name     Parsed VTs feed name.
+ * @param[out]  feed_vendor   Parsed VTs feed vendor.
+ * @param[out]  feed_home     Parsed VTs feed home URL.
+ * @param[out]  error         Pointer to error, if any.
+ *
+ * @return 0 if success, 1 if error.
+ */
+int
+osp_get_vts_feed_info (osp_connection_t *connection, char **vts_version,
+                       char **feed_name, char **feed_vendor, char **feed_home,
+                       char **error)
+{
+  entity_t entity, vts;
+  const char *version, *name, *vendor, *home;
+  const char *status, *status_text;
+  osp_get_vts_opts_t get_vts_opts;
+
+  if (!connection)
+    return 1;
+
+  get_vts_opts = osp_get_vts_opts_default;
+  get_vts_opts.version_only = 1;
+  if (osp_get_vts_ext (connection, get_vts_opts, &entity))
+    return 1;
+
+  status = entity_attribute (entity, "status");
+
+  if (status != NULL && !strcmp (status, "400"))
+    {
+      status_text = entity_attribute (entity, "status_text");
+      g_debug ("%s: %s - %s.", __func__, status, status_text);
+      if (error)
+        *error = g_strdup (status_text);
+      free_entity (entity);
+      return 1;
+    }
+
+  vts = entity_child (entity, "vts");
+  if (!vts)
+    {
+      g_warning ("%s: element VTS missing.", __func__);
+      free_entity (entity);
+      return 1;
+    }
+
+  version = entity_attribute (vts, "vts_version");
+  name = entity_attribute (vts, "feed_name");
+  vendor = entity_attribute (vts, "feed_vendor");
+  home = entity_attribute (vts, "feed_home");
+
+  if (vts_version)
+    *vts_version = version ? g_strdup (version) : NULL;
+  if (feed_name)
+    *feed_name = name ? g_strdup (name) : NULL;
+  if (feed_vendor)
+    *feed_vendor = vendor ? g_strdup (vendor) : NULL;
+  if (feed_home)
+    *feed_home = home ? g_strdup (home) : NULL;
+
+  free_entity (entity);
+  return 0;
+}
+
 /**
  * @brief Get all VTs from an OSP server.
  *
